@@ -6,6 +6,10 @@ from . import linearregression
 from . import multivariate_normal
 from . import normal
 from . import poisson
+from . import metatree
+from . import contexttree
+from . import gaussianmixture
+from . import hiddenmarkovnormal
 
 __all__ = ['bernoulli',
            'categorical',
@@ -14,5 +18,9 @@ __all__ = ['bernoulli',
            'linearregression',
            'multivariate_normal',
            'normal',
-           'poisson'
+           'poisson',
+           'metatree',
+           'contexttree',
+           'gaussianmixture',
+           'hiddenmarkovnormal',
            ]
\ No newline at end of file
