@@ -1,7 +1,5 @@
-"""
-Author: Yuta Nakahara <yuta.nakahara@aoni.waseda.jp>
-"""
-
+# Code Author
+# Yuta Nakahara <yuta.nakahara@aoni.waseda.jp>
 class ParameterFormatError(Exception):
     def __init__(self, value):
         self.value = value
